--- src/log.c.orig	Sun Sep 26 02:00:34 1999
+++ src/log.c	Tue Sep 28 13:30:12 1999
@@ -44,7 +44,7 @@
 static int syslog_discard = FALSE;
 static int logstderr = TRUE;
 static int debug_level = DEBUG0;	/* Default is no debug logging */
-static int facility = LOG_DAEMON;
+static int facility = LOG_FTP;
 static int set_facility = -1;
 static char *syslog_fn = NULL;
 static char *syslog_hostname;
@@ -739,7 +739,7 @@
   log(priority,facility,buf);
 }
 
 /* Like log_pri(), but sends the log entry in the LOG_AUTHPRIV
  * facility (presumable it doesn't need to be seen by everyone
  */
 
@@ -754,7 +754,7 @@
 
   buf[1023] = '\0';
 
-  log(priority, LOG_AUTHPRIV, buf);
+  log(priority, LOG_FTP, buf);
 }
 
 /* Disable logging to stderr, should be done right before forking
@@ -739,7 +739,7 @@
 }
 
-/* Like log_pri(), but sends the log entry in the LOG_AUTHPRIV
+/* Like log_pri(), but sends the log entry in the LOG_FTP
  * facility (presumable it doesn't need to be seen by everyone
  */
